======
String
======

The following methods are available under the `expr.str` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.str.concat
    Expr.str.contains
    Expr.str.contains_any
    Expr.str.count_matches
    Expr.str.decode
    Expr.str.encode
    Expr.str.ends_with
    Expr.str.escape_regex
    Expr.str.explode
    Expr.str.extract
    Expr.str.extract_all
    Expr.str.extract_groups
    Expr.str.extract_many
    Expr.str.find
    Expr.str.find_many
    Expr.str.head
    Expr.str.join
    Expr.str.json_decode
    Expr.str.json_path_match
    Expr.str.len_bytes
    Expr.str.len_chars
    Expr.str.normalize
    Expr.str.pad_end
    Expr.str.pad_start
    Expr.str.replace
    Expr.str.replace_all
    Expr.str.replace_many
    Expr.str.reverse
    Expr.str.slice
    Expr.str.split
    Expr.str.split_exact
    Expr.str.splitn
    Expr.str.starts_with
    Expr.str.strip_chars
    Expr.str.strip_chars_start
    Expr.str.strip_chars_end
    Expr.str.strip_prefix
    Expr.str.strip_suffix
    Expr.str.strptime
    Expr.str.tail
    Expr.str.to_date
    Expr.str.to_datetime
    Expr.str.to_decimal
    Expr.str.to_integer
    Expr.str.to_lowercase
    Expr.str.to_time
    Expr.str.to_titlecase
    Expr.str.to_uppercase
    Expr.str.zfill
